import axios from 'axios';
import config from '../config/index';
import errorHandle from './errorHandle';
import store from '../store/index';

const path = config.SERVER_URL + '/dcxy/api/gx/construction';
// 创建axios实例
const service = axios.create({
  baseURL: path, // api的base_url
  timeout: 10000,
});
// request拦截器
service.interceptors.request.use(
  conf => {
    let token = store.getToken();

    conf.headers = {
      ...conf.headers,
      reqSource: 'wx',
      token: token ? token : '',
    };
    return conf;
  },
  error => {
    // Do something with request error
    console.log(error); // for debug
    Promise.reject(error);
  }
);

// respone拦截器
service.interceptors.response.use(response => {
  const res = response.data;

  /**
   * code为非'0'是抛错
   */
  if (res.code !== 1000) {
    return Promise.reject(response.data);
  } else {
    return response.data;
  }
}, errorHandle);

export default service;
