import React from 'react';
import PropTypes from 'prop-types';
import styles from './style.css';
import { Toast } from 'antd-mobile';
import searchIcon from '../../images/Search/default_search_icon@2x.png';
import { getPositionsList } from '../../api/index';
import UserInfoContext from '../../context/userinfo-context';
import { filterEmoji } from '../../utils/index';

export class Location extends React.Component {
  static propTypes = {
    campusId: PropTypes.number,
  };
  constructor(props) {
    super(props);
    this.state = {
      showToast: false,
      localText: '',
      localList: [],
      pagination: {},
    };
  }
  componentWillMount() {
    const { setTitle, userinfo } = this.props;
    setTitle('检索位置');
    getPositionsList({
      campusId: userinfo.campusId,
    })
      .then(res => {
        const { list, ...pagination } = res.data;
        this.setState({
          localList: list,
          pagination,
        });
      })
      .catch(err => {
        Toast.fail(err.msg || '请求失败');
      });
  }
  showToast = text => {
    this.setState({
      showToast: true,
      localText: text,
    });
    let elem = document.getElementById(text);
    elem.scrollIntoView();
    setTimeout(() => {
      this.setState({
        showToast: false,
      });
    }, 1000);
  };
  changeHandle = e => {
    let value = e.target.value.trim();
    value = filterEmoji(value);
    this.setState({
      localText: value,
    });
  };
  searchList = () => {
    Toast.loading('', 20);
    const { userinfo } = this.props;
    const { localText } = this.state;
    getPositionsList({
      campusId: userinfo.campusId,
      name: localText,
    })
      .then(res => {
        const { list, ...pagination } = res.data;
        this.setState({
          localList: list,
          pagination,
        });
        Toast.hide();
      })
      .catch(err => {
        Toast.fail(err.msg || '请求失败');
      });
  };
  bindEquipment = (positionId, position) => {
    const { history, updateUserInfo, userinfo } = this.props;
    updateUserInfo({
      position: {
        ...userinfo.position,
        id: positionId,
        position,
      },
    });
    history.goBack();
  };
  render() {
    const { showToast, localText, localList } = this.state;
    return (
      <div className={'appContent ' + styles.Location}>
        <div className={styles.searchBox}>
          <input
            className={'br8 ' + styles.searchInput}
            type='text'
            onChange={this.changeHandle}
            placeholder='请输入位置关键词'
          />
          <span className={styles.searchBtn} onClick={this.searchList}>
            <i className={styles.searchIcon}>
              <img src={searchIcon} alt='' />
            </i>
            搜索
          </span>
        </div>
        <div className={styles.infoBar}>
          {localList.map(item => (
            <div
              key={item.firstLetter}
              className={styles.infoItem}
              onClick={() => this.showToast(item.firstLetter)}
            >
              {item.firstLetter}
            </div>
          ))}
        </div>
        <div
          className={
            showToast
              ? styles.show + ' br8 ' + styles.infoToast
              : 'br8 ' + styles.infoToast
          }
        >
          {localText}
        </div>
        <div className={styles.locationList}>
          {localList.map(area => (
            <div key={area.firstLetter} className={styles.locationArea}>
              <div id={area.firstLetter} className={styles.locationTitle}>
                {area.firstLetter}
              </div>
              {area.positions.map((location, index) => (
                <div
                  key={index}
                  className={styles.locationItem}
                  onClick={() =>
                    this.bindEquipment(location.id, location.position)
                  }
                >
                  {location.position}
                </div>
              ))}
            </div>
          ))}
        </div>
      </div>
    );
  }
}

export default props => (
  <UserInfoContext.Consumer>
    {({ userinfo, updateUserInfo }) => (
      <Location
        {...props}
        userinfo={userinfo}
        updateUserInfo={updateUserInfo}
      />
    )}
  </UserInfoContext.Consumer>
);
