import React from 'react';
import PropTypes from 'prop-types';
import { Button, Toast } from 'antd-mobile';
import styles from './style.scss';
import eqIcon from '../../images/Equipment/equip_number_icon@2x.png';
import rateIcon from '../../images/Rate/rate_detail_icon@2x.png';
import { fetchRate, activateRate } from '../../api/index';

export class Index extends React.Component {
  static propTypes = {
    name: PropTypes.string,
  };
  constructor(props) {
    super(props);
    this.state = {
      mode: null,
      type: 1,
      coldMeasure: '0',
      coldMoney: '0.00',
      hotMeasure: '0',
      hotMoney: '0.00',
      warmMeasure: '0',
      warmMoney: '0.00',
    };
  }

  componentWillMount() {
    const { setTitle } = this.props;
    const { deviceCode } = this.props.match.params;
    setTitle('费率激活');
    fetchRate(deviceCode)
      .then(res => {
        console.log(res);
        const {
          coldMeasure,
          coldMoney,
          hotMeasure,
          hotMoney,
          mode,
          warmMeasure,
          warmMoney,
          type,
        } = res.data;
        this.setState({
          coldMeasure,
          coldMoney: (coldMoney / 100).toFixed(2),
          hotMeasure,
          hotMoney: (hotMoney / 100).toFixed(2),
          warmMeasure,
          warmMoney: (warmMoney / 100).toFixed(2),
          mode,
          type,
        });
      })
      .catch(err => {
        Toast.fail(err.msg || '费率请求失败');
      });
  }
  clickHandle = () => {
    Toast.loading('', 20);
    const { deviceCode } = this.props.match.params;
    activateRate({ deviceCode })
      .then(res => {
        console.log(res);
        Toast.success(res.msg);
      })
      .catch(err => {
        Toast.fail(err.msg || '费率请求失败');
      });
  };
  render() {
    const { deviceCode } = this.props.match.params;
    const {
      coldMeasure,
      coldMoney,
      hotMeasure,
      hotMoney,
      warmMeasure,
      warmMoney,
      mode,
      type,
    } = this.state;

    let rateTypeText = 'ML|S';
    if (mode === 1) {
      rateTypeText = 'ML';
    }
    if (mode === 2) {
      rateTypeText = 'S';
    }

    return (
      <div className={'appContent ' + styles.RateActivity}>
        <div className={styles.inputBox}>
          <i className={styles.inputIcon}>
            <img src={eqIcon} alt='' />
          </i>
          <span className={'ellipsis ' + styles.inputText}>
            设备编号：
            {deviceCode}
          </span>
        </div>
        <div className={styles.inputBox}>
          <i className={styles.inputIcon}>
            <img src={rateIcon} alt='' />
          </i>
          <span className={'ellipsis ' + styles.inputText}>费率详情:</span>
        </div>
        <div className={styles.rateBox}>
          {type === 2
            ? [
                <div className={styles.rateArea}>
                  <div className={styles.rateTitle}>
                    <span className={styles.rateItem}>一路费率价格(元)</span>
                    <span className={styles.rateItem}>
                      费率单位({rateTypeText})
                    </span>
                  </div>
                  <div className={styles.line} />
                  <div className={styles.ratePrice}>
                    <span className={styles.rateItem}>{coldMoney}</span>
                    <span className={styles.rateItem}>{coldMeasure}</span>
                  </div>
                </div>,
                <div className={styles.rateArea}>
                  <div className={styles.rateTitle}>
                    <span className={styles.rateItem}>二路费率价格(元)</span>
                    <span className={styles.rateItem}>
                      费率单位({rateTypeText})
                    </span>
                  </div>
                  <div className={styles.line} />
                  <div className={styles.ratePrice}>
                    <span className={styles.rateItem}>{hotMoney}</span>
                    <span className={styles.rateItem}>{hotMeasure}</span>
                  </div>
                </div>,
                <div className={styles.rateArea}>
                  <div className={styles.rateTitle}>
                    <span className={styles.rateItem}>三路费率价格(元)</span>
                    <span className={styles.rateItem}>
                      费率单位({rateTypeText})
                    </span>
                  </div>
                  <div className={styles.line} />
                  <div className={styles.ratePrice}>
                    <span className={styles.rateItem}>{warmMoney}</span>
                    <span className={styles.rateItem}>{warmMeasure}</span>
                  </div>
                </div>,
              ]
            : [
                <div className={styles.rateArea}>
                  <div className={styles.rateTitle}>
                    <span className={styles.rateItem}>冷水费率价格(元)</span>
                    <span className={styles.rateItem}>
                      冷水费率单位({rateTypeText})
                    </span>
                  </div>
                  <div className={styles.line} />
                  <div className={styles.ratePrice}>
                    <span className={styles.rateItem}>{coldMoney}</span>
                    <span className={styles.rateItem}>{coldMeasure}</span>
                  </div>
                </div>,
                <div className={styles.rateArea}>
                  <div className={styles.rateTitle}>
                    <span className={styles.rateItem}>热水费率价格(元)</span>
                    <span className={styles.rateItem}>
                      热水费率单位({rateTypeText})
                    </span>
                  </div>
                  <div className={styles.line} />
                  <div className={styles.ratePrice}>
                    <span className={styles.rateItem}>{hotMoney}</span>
                    <span className={styles.rateItem}>{hotMeasure}</span>
                  </div>
                </div>,
              ]}
        </div>
        <Button
          type='primary'
          className={styles.btn}
          onClick={this.clickHandle}
        >
          激活费率
        </Button>
      </div>
    );
  }
}

export default Index;
